** e-drone


* Install
```
> pip install e_drone
> pip --no-cache-dir install e_drone
```

* Upgrade
```
> pip install --upgrade e_drone
```

* Uninstall
```
> pip uninstall e_drone
```



** Link


* PyPI
    * https://pypi.org/project/e-drone/


* Documents for E-Drone python library.
    * https://byrobot.github.io/documents/kr/products/e_drone/library/python/e_drone/


* BYROBOT Dev
    * http://dev.byrobot.co.kr/


* Forum
    * https://groups.google.com/d/forum/byrobot


* Discord
    * https://discord.gg/UVVJMye


* Youtube
    * https://www.youtube.com/user/BYROBOTCO


* Facebook
    * https://www.facebook.com/Byrobot.Drones



BYROBOT

